@@ -14,6 +14,7 @@ from askdata.security import SignUp
 from requests.adapters import HTTPAdapter
 from urllib3.util.retry import Retry
 from typing import TYPE_CHECKING
+
 if TYPE_CHECKING:
     from askdata.askdata_client import Askdata
 import re
@@ -33,7 +34,6 @@ with open(yaml_path, 'r') as file:
     url_list = yaml.load(file, Loader=yaml.FullLoader)
 
 
-
 class Agent(Insight, Channel, Catalog, Dataset):
     '''
     Agent Object
@@ -97,7 +97,6 @@ class Agent(Insight, Channel, Catalog, Dataset):
         if self._env == 'prod':
             self._base_url = url_list['BASE_URL_FEED_PROD']
 
-
         if self._env == 'dev':
             self._base_url_ch = url_list['BASE_URL_FEED_DEV']
         if self._env == 'qa':
@@ -132,8 +131,9 @@ class Agent(Insight, Channel, Catalog, Dataset):
         response = requests.post(url=request_agent_url, headers=self._headers, json=data)
         response.raise_for_status()
         r = response.json()
-        #dataframe creation
-        df = pd.DataFrame(np.array(r[0]['attachment']['body'][0]['details']['rows']), columns=r[0]['attachment']['body'][0]['details']['columns'])
+        # dataframe creation
+        df = pd.DataFrame(np.array(r[0]['attachment']['body'][0]['details']['rows']),
+                          columns=r[0]['attachment']['body'][0]['details']['columns'])
 
         return df
 
@@ -176,7 +176,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
         retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
         s.mount('https://', HTTPAdapter(max_retries=retries))
 
-        authentication_url = self._base_url_askdata + '/smartdataset/datasets/'+dataset_slug+'/sdk'
+        authentication_url = self._base_url_askdata + '/smartdataset/datasets/' + dataset_slug + '/sdk'
         logging.info("AUTH URL {}".format(authentication_url))
 
         headers = {
@@ -193,7 +193,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
         retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
         s.mount('https://', HTTPAdapter(max_retries=retries))
 
-        authentication_url = self._base_url_askdata + '/smartbot/agents/'+agent_slug+'/datasets/'+dataset_slug+'/parquet'
+        authentication_url = self._base_url_askdata + '/smartbot/agents/' + agent_slug + '/datasets/' + dataset_slug + '/parquet'
         logging.info("AUTH URL {}".format(authentication_url))
         file = {'file': open(file_path, 'rb')}
         headers = {"Authorization": "Bearer" + " " + self._token}
@@ -201,7 +201,6 @@ class Agent(Insight, Channel, Catalog, Dataset):
         response.raise_for_status()
         r = response.json()
 
-
     def update_parquet_dataset(self, agent_slug, dataset_id, file_path, strategy):
 
         s = requests.Session()
@@ -209,7 +208,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
         retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
         s.mount('https://', HTTPAdapter(max_retries=retries))
 
-        authentication_url = self._base_url_askdata + '/smartbot/agents/'+agent_slug+'/datasets/'+dataset_id+'/parquet?strategy='+strategy
+        authentication_url = self._base_url_askdata + '/smartbot/agents/' + agent_slug + '/datasets/' + dataset_id + '/parquet?strategy=' + strategy
         logging.info("AUTH URL {}".format(authentication_url))
         file = {'file': open(file_path, 'rb')}
         headers = {"Authorization": "Bearer" + " " + self._token}
@@ -217,7 +216,6 @@ class Agent(Insight, Channel, Catalog, Dataset):
         response.raise_for_status()
         r = response.json()
 
-
     def load_dataset(self, datasetSlug):
 
         dataset = self.get_dataset_by_slug(self._agentId, datasetSlug)
@@ -227,7 +225,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
         retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
         s.mount('https://', HTTPAdapter(max_retries=retries))
 
-        authentication_url = self._base_url_askdata + '/smartdataset/datasets/' + dataset["id"] +'/grid/data'
+        authentication_url = self._base_url_askdata + '/smartdataset/datasets/' + dataset["id"] + '/grid/data'
         logging.info("AUTH URL {}".format(authentication_url))
 
         headers = {"Authorization": "Bearer" + " " + self._token}
@@ -236,29 +234,27 @@ class Agent(Insight, Channel, Catalog, Dataset):
         r = response.json()
         return pd.DataFrame(r['payload']['data'])
 
-
-    def get_dataset_by_slug(self, agent_id, slug:str) -> Dataset:
+    def get_dataset_by_slug(self, agent_id, slug: str) -> Dataset:
         s = requests.Session()
         s.keep_alive = False
         retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
         s.mount('https://', HTTPAdapter(max_retries=retries))
 
-        authentication_url = self._base_url_askdata + '/smartdataset/datasets/slug/'+ agent_id+'/'+ slug
+        authentication_url = self._base_url_askdata + '/smartdataset/datasets/slug/' + agent_id + '/' + slug
         logging.info("AUTH URL {}".format(authentication_url))
 
         headers = {"Authorization": "Bearer" + " " + self._token}
         response = s.get(url=authentication_url, headers=headers)
         response.raise_for_status()
         r = response.json()
-        if(r["found"]):
+        if (r["found"]):
             return r["dataset"]
         else:
             return None
 
-
     def _update_dataset_icon(self, dataset_id, icon_url):
 
-        url = self._base_url_askdata+"/smartdataset/datasets/"+dataset_id+"/settings"
+        url = self._base_url_askdata + "/smartdataset/datasets/" + dataset_id + "/settings"
 
         s = requests.Session()
         s.keep_alive = False
@@ -294,8 +290,8 @@ class Agent(Insight, Channel, Catalog, Dataset):
         response = s.put(url=url, json=settings, headers=headers)
         response.raise_for_status()
 
-
-    def create_dataset(self, dataframe:pd.DataFrame, dataset_name:str, slug: str, icon_url=None, settings: dict = None):
+    def create_dataset(self, dataframe: pd.DataFrame, dataset_name: str, slug: str, icon_url=None,
+                       settings: dict = None):
 
         for col in dataframe.columns:
             if (dataframe[col].dtypes == "datetime64[ns]"):
@@ -304,19 +300,18 @@ class Agent(Insight, Channel, Catalog, Dataset):
         body = {"label": dataset_name, "rows": dataframe.to_dict(orient="record")}
 
         settings_list = []
-        if(settings != None):
+        if (settings != None):
             for key in settings.keys():
                 settings[key]["column_name"] = key
                 settings_list.append(settings[key])
             body["settings"] = settings_list
 
-
         s = requests.Session()
         s.keep_alive = False
         retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
         s.mount('https://', HTTPAdapter(max_retries=retries))
 
-        url = self._base_url_askdata + '/smartbot/agents/'+self._agentId+'/datasets/'+slug+'/sdk'
+        url = self._base_url_askdata + '/smartbot/agents/' + self._agentId + '/datasets/' + slug + '/sdk'
         logging.info("AUTH URL {}".format(url))
 
         headers = {
@@ -329,10 +324,11 @@ class Agent(Insight, Channel, Catalog, Dataset):
 
         dataset_id = response.json()["id"]
 
-        if(icon_url!=None):
+        if (icon_url != None):
             self._update_dataset_icon(dataset_id, icon_url)
 
-    def update_dataset(self, dataframe: pd.DataFrame, dataset_name: str, slug: str, icon_url=None, settings: dict = None):
+    def update_dataset(self, dataframe: pd.DataFrame, dataset_name: str, slug: str, icon_url=None,
+                       settings: dict = None):
 
         for col in dataframe.columns:
             if (dataframe[col].dtypes == "datetime64[ns]"):
@@ -366,7 +362,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
         response.raise_for_status()
         dataset_id = response.json()["id"]
 
-        if(icon_url!=None):
+        if (icon_url != None):
             self._update_dataset_icon(dataset_id, icon_url)
 
     '''La prima chiave è la stringa colonna del dataframe. Per ogni chiave ho dei setting:
@@ -391,20 +387,18 @@ class Agent(Insight, Channel, Catalog, Dataset):
     }
     '''
 
-
-    def create_or_replace_dataset(self, dataframe:pd.DataFrame, dataset_name:str, slug:str, icon_url=None, settings:dict = None):
-        #Check if dataset exists
+    def create_or_replace_dataset(self, dataframe: pd.DataFrame, dataset_name: str, slug: str, icon_url=None,
+                                  settings: dict = None):
+        # Check if dataset exists
         dataset = self.get_dataset_by_slug(self._agentId, slug)
 
-        if(dataset != None):
-            #If it exists update it
+        if (dataset != None):
+            # If it exists update it
             self.update_dataset(dataframe, dataset_name, slug, icon_url, settings)
         else:
             # If not exists create a new one
             self.create_dataset(dataframe, dataset_name, slug, icon_url, settings)
 
-
-
     def delete_dataset(self, slug='', dataset_id=''):
 
         if slug != '':
@@ -417,20 +411,20 @@ class Agent(Insight, Channel, Catalog, Dataset):
         else:
             raise Exception('takes 2 positional arguments "slug, datset_id" but 0 were given')
 
-    def create_datacard(self, channel: str, title: str,  search:str = "", slug: str = None, replace:bool = False):
+    def create_datacard(self, channel: str, title: str, search: str = "", slug: str = None, replace: bool = False):
 
-        if(replace==True and slug!= None):
+        if (replace == True and slug != None):
             try:
                 datacard = self.get_datacard(slug)
                 datacard.delete()
             except:
                 pass
-        elif(replace==True and slug!= None):
+        elif (replace == True and slug != None):
             print("Please specify a datacard slug to replace!")
             return
 
         channel = self.get_channel(self._agentId, channel)
-        if channel!=None:
+        if channel != None:
             channel_id = channel["id"]
         else:
             channel_id = self.create_channel(channel)
@@ -451,7 +445,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
         if self._env == 'prod':
             smart_insight_url = url_list['BASE_URL_INSIGHT_PROD']
 
-        url = smart_insight_url+'/definitions'
+        url = smart_insight_url + '/definitions'
 
         s = requests.Session()
         s.keep_alive = False
@@ -468,7 +462,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
         response.raise_for_status()
         definition = response.json()
 
-        if(search!=""):
+        if (search != ""):
             body_query = {"nl": search, "language": "en"}
 
             s = requests.Session()
@@ -480,16 +474,16 @@ class Agent(Insight, Channel, Catalog, Dataset):
                 "Content-Type": "application/json",
                 "Authorization": "Bearer" + " " + self._token
             }
-            query_url = smart_insight_url+'/definitions/'+definition["id"]+'/nl_queries/'+definition["components"][0]["id"]+'/nl'
+            query_url = smart_insight_url + '/definitions/' + definition["id"] + '/nl_queries/' + \
+                        definition["components"][0]["id"] + '/nl'
             logging.info("QUERY URL {}".format(query_url))
             r = s.put(url=query_url, json=body_query, headers=headers)
 
         return Insight_Definition(self._env, self._token, definition)
 
-
     def get_datacard(self, slug):
 
-        url = self.smart_insight_url+"/definitions/agent/"+self._agentId+"/slug/"+slug
+        url = self.smart_insight_url + "/definitions/agent/" + self._agentId + "/slug/" + slug
 
         s = requests.Session()
         s.keep_alive = False
@@ -502,12 +496,11 @@ class Agent(Insight, Channel, Catalog, Dataset):
         definition = r.json()
         return Insight_Definition(self._env, self._token, definition)
 
-
     def create_channel(self, name, icon='https://storage.googleapis.com/askdata/smartfeed/icons/Channel@2x.png',
                        visibility='PRIVATE'):
 
         data = {
-            "userId" : self.userid,
+            "userId": self.userid,
             "name": name,
             "icon": icon,
             "agentId": self._agentId,
@@ -526,7 +519,6 @@ class Agent(Insight, Channel, Catalog, Dataset):
         r.raise_for_status()
         return r.json()['id']
 
-
     def get_channel(self, agent_id, channel_code):
 
         s = requests.Session()
@@ -534,16 +526,15 @@ class Agent(Insight, Channel, Catalog, Dataset):
         retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
         s.mount('https://', HTTPAdapter(max_retries=retries))
 
-        url = self._base_url_ch + '/channels?agentId='+agent_id+'&slug='+channel_code
+        url = self._base_url_ch + '/channels?agentId=' + agent_id + '&slug=' + channel_code
         r = s.get(url=url, headers=self._headers)
         r.raise_for_status()
-        if(r != None and r.json() != []):
+        if (r != None and r.json() != []):
             return r.json()[0]
         else:
             return None
 
-
-    def get_dataset_slug_from_id(self, dataset_id:str)->str:
+    def get_dataset_slug_from_id(self, dataset_id: str) -> str:
         """
         get dataset slug by the dataset id instantiated with slug
         :param dataset_id: str
@@ -625,7 +616,7 @@ class Askdata(SignUp):
             self.username = r_userid.json()['userName']
 
     def agent(self, slug="", agent_id="") -> 'Agent':
-        #Agent.__init__(self, self, slug=slug)
+        # Agent.__init__(self, self, slug=slug)
         return Agent(self, slug=slug, agent_id=agent_id)
 
     def load_agents(self):
