@@ -87,17 +87,18 @@ class Query:
 
         fields_with_agg = []
         for field in self.fields:
+            column = "'" + field.column + "'"
             if field.aggregation is not None:
                 if isinstance(field.aggregation, SQLFunction):
-                    field_with_agg = field.aggregation.name + " ( " + field.column + " )"
+                    field_with_agg = field.aggregation.name + " ( " + column + " )"
                 elif isinstance(field.aggregation, TimeDimensionGranularity):
-                    field_with_agg = field.column
+                    field_with_agg = column
                 else:
-                    field_with_agg = field.aggregation + " ( " + field.column + " )"
+                    field_with_agg = field.aggregation + " ( " + column + " )"
             else:
-                field_with_agg = field.column
+                field_with_agg = column
             if field.alias is not None:
-                field_with_agg += " AS " + field.alias
+                field_with_agg += " AS " + "'" + field.alias + "'"
             fields_with_agg.append(field_with_agg)
 
         formatted_fields = ", ".join(fields_with_agg)
@@ -121,7 +122,7 @@ class Query:
             for condition in self.where:
                 vars = []
                 for var in condition.value:
-                    var = str(var)
+                    var = "'" + str(var) + "'"
                     if var.isnumeric():
                         vars.append(var)
                     else:
@@ -146,7 +147,7 @@ class Query:
                     # else:
                     #     field_with_agg = condition.field.aggregation + " ( " + condition.field.column + " )"
                 else:
-                    field_with_agg = condition.field.column
+                    field_with_agg = "'" + condition.field.column + "'"
                     where_condition = (
                             field_with_agg + " " + operator + " " + str(formatted_value)
                     )
@@ -162,7 +163,7 @@ class Query:
         for field in self.fields:
             if field.entityType is not None:
                 if "P_DIMENSION" == field.entityType or "P_TIMEDIM" == field.entityType:
-                    group_conditions.append(field.column)
+                    group_conditions.append("'"+field.column+"'")
         if group_conditions:
             formatted_group = ", ".join(group_conditions)
             sql_groupBy = sql_groupBy.format(formatted_group)
@@ -194,18 +195,19 @@ class Query:
                         operator = "<="
                     elif operator == "EQ":
                         operator = "=="
+                column = "'" + condition.field.column + "'"
                 if condition.field.aggregation is not None:
                     if isinstance(condition.field.aggregation, SQLFunction):
-                        field_with_agg = condition.field.aggregation.name + " ( " + condition.field.column + " )"
+                        field_with_agg = condition.field.aggregation.name + " ( " + column + " )"
                     elif isinstance(condition.field.aggregation, TimeDimensionGranularity):
-                        field_with_agg = condition.field.column
+                        field_with_agg = column
                     else:
-                        field_with_agg = condition.field.aggregation + " ( " + condition.field.column + " )"
+                        field_with_agg = condition.field.aggregation + " ( " + column + " )"
                 else:
-                    field_with_agg = condition.field.column
+                    field_with_agg = column
                 having_condition = (
-                            field_with_agg + " " + operator + " " + str(formatted_value)
-                    )
+                        field_with_agg + " " + operator + " " + str(formatted_value)
+                )
                 all_having_conditions.append(having_condition)
             formatted_having_conditions = " AND ".join(all_having_conditions)
             sql_having = sql_having.format(formatted_having_conditions)
@@ -217,7 +219,7 @@ class Query:
 
             for sorting in self.orderBy:
                 sort_order = sorting.order.name
-                sort_condition = sorting.field + " " + sort_order
+                sort_condition = "'" + sorting.field + "' " + sort_order
                 sorting_conditions.append(sort_condition)
 
             formatted_sorting = ", ".join(sorting_conditions)
